@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2019 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2020 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -23,16 +23,17 @@ Defines a CompletionView which uses CompletionFiterModel and CompletionModel
 subclasses to provide completions.
 """
 
-import typing  # pylint: disable=unused-import,useless-suppression
-
+import typing
 
 from PyQt5.QtWidgets import QTreeView, QSizePolicy, QStyleFactory, QWidget
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QItemSelectionModel, QSize
 
-from qutebrowser.config import config
+from qutebrowser.config import config, stylesheet
 from qutebrowser.completion import completiondelegate
-from qutebrowser.utils import utils, usertypes, debug, log, objreg
+from qutebrowser.utils import utils, usertypes, debug, log
 from qutebrowser.api import cmdutils
+if typing.TYPE_CHECKING:
+    from qutebrowser.mainwindow.statusbar import command
 
 
 class CompletionView(QTreeView):
@@ -50,6 +51,7 @@ class CompletionView(QTreeView):
         _delegate: The item delegate used.
         _column_widths: A list of column widths, in percent.
         _active: Whether a selection is active.
+        _cmd: The statusbar Command object.
 
     Signals:
         update_geometry: Emitted when the completion should be resized.
@@ -108,18 +110,22 @@ class CompletionView(QTreeView):
     update_geometry = pyqtSignal()
     selection_changed = pyqtSignal(str)
 
-    def __init__(self, win_id: int, parent: QWidget = None) -> None:
+    def __init__(self, *,
+                 cmd: 'command.Command',
+                 win_id: int,
+                 parent: QWidget = None) -> None:
         super().__init__(parent)
         self.pattern = None  # type: typing.Optional[str]
         self._win_id = win_id
-        config.instance.changed.connect(self._on_config_changed)
-
+        self._cmd = cmd
         self._active = False
 
+        config.instance.changed.connect(self._on_config_changed)
+
         self._delegate = completiondelegate.CompletionItemDelegate(self)
         self.setItemDelegate(self._delegate)
         self.setStyle(QStyleFactory.create('Fusion'))
-        config.set_register_stylesheet(self)
+        stylesheet.set_register(self)
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
         self.setHeaderHidden(True)
         self.setAlternatingRowColors(True)
@@ -243,15 +249,13 @@ class CompletionView(QTreeView):
             history: Navigate through command history if no text was typed.
         """
         if history:
-            status = objreg.get('status-command', scope='window',
-                                window=self._win_id)
-            if (status.text() == ':' or status.history.is_browsing() or
+            if (self._cmd.text() == ':' or self._cmd.history.is_browsing() or
                     not self._active):
                 if which == 'next':
-                    status.command_history_next()
+                    self._cmd.command_history_next()
                     return
                 elif which == 'prev':
-                    status.command_history_prev()
+                    self._cmd.command_history_prev()
                     return
                 else:
                     raise cmdutils.CommandError("Can't combine --history with "
@@ -273,7 +277,9 @@ class CompletionView(QTreeView):
             return
 
         selmodel.setCurrentIndex(
-            idx, QItemSelectionModel.ClearAndSelect | QItemSelectionModel.Rows)
+            idx,
+            QItemSelectionModel.ClearAndSelect |  # type: ignore[arg-type]
+            QItemSelectionModel.Rows)
 
         # if the last item is focused, try to fetch more
         if idx.row() == self.model().rowCount(idx.parent()) - 1:
@@ -412,9 +418,7 @@ class CompletionView(QTreeView):
         Args:
             sel: Use the primary selection instead of the clipboard.
         """
-        status = objreg.get('status-command', scope='window',
-                            window=self._win_id)
-        text = status.selectedText()
+        text = self._cmd.selectedText()
         if not text:
             index = self.currentIndex()
             if not index.isValid():
