@@ -65,6 +65,7 @@ from qutebrowser.config import configexc, configutils
 from qutebrowser.utils import (standarddir, utils, qtutils, urlutils, urlmatch,
                                usertypes)
 from qutebrowser.keyinput import keyutils
+from qutebrowser.browser.network import pac
 
 
 class _SystemProxy:
@@ -81,7 +82,8 @@ BOOLEAN_STATES = {'1': True, 'yes': True, 'true': True, 'on': True,
 
 _Completions = typing.Optional[typing.Iterable[typing.Tuple[str, str]]]
 _StrUnset = typing.Union[str, usertypes.Unset]
-_StrUnsetNone = typing.Union[None, str, usertypes.Unset]
+_UnsetNone = typing.Union[None, usertypes.Unset]
+_StrUnsetNone = typing.Union[str, _UnsetNone]
 
 
 class ValidValues:
@@ -702,8 +704,10 @@ class Bool(BaseType):
         super().__init__(none_ok)
         self.valid_values = ValidValues('true', 'false', generate_docs=False)
 
-    def to_py(self, value: typing.Optional[bool]) -> typing.Optional[bool]:
+    def to_py(self,
+              value: typing.Union[bool, str, None]) -> typing.Optional[bool]:
         self._basic_py_validation(value, bool)
+        assert not isinstance(value, str)
         return value
 
     def from_str(self, value: str) -> typing.Optional[bool]:
@@ -733,15 +737,15 @@ class BoolAsk(Bool):
         super().__init__(none_ok)
         self.valid_values = ValidValues('true', 'false', 'ask')
 
-    def to_py(self,  # type: ignore
+    def to_py(self,  # type: ignore[override]
               value: typing.Union[bool, str]) -> typing.Union[bool, str, None]:
         # basic validation unneeded if it's == 'ask' and done by Bool if we
         # call super().to_py
         if isinstance(value, str) and value.lower() == 'ask':
             return 'ask'
-        return super().to_py(value)  # type: ignore
+        return super().to_py(value)
 
-    def from_str(self,  # type: ignore
+    def from_str(self,  # type: ignore[override]
                  value: str) -> typing.Union[bool, str, None]:
         # basic validation unneeded if it's == 'ask' and done by Bool if we
         # call super().from_str
@@ -794,11 +798,14 @@ class _Numeric(BaseType):  # pylint: disable=abstract-method
                 assert isinstance(bound, (int, float)), bound
             return bound
 
-    def _validate_bounds(self, value: typing.Union[None, int, float],
+    def _validate_bounds(self,
+                         value: typing.Union[int, float, _UnsetNone],
                          suffix: str = '') -> None:
         """Validate self.minval and self.maxval."""
         if value is None:
             return
+        elif isinstance(value, usertypes.Unset):
+            return
         elif self.minval is not None and value < self.minval:
             raise configexc.ValidationError(
                 value, "must be {}{} or bigger!".format(self.minval, suffix))
@@ -834,7 +841,10 @@ class Int(_Numeric):
         self.to_py(intval)
         return intval
 
-    def to_py(self, value: typing.Optional[int]) -> typing.Optional[int]:
+    def to_py(
+            self,
+            value: typing.Union[int, _UnsetNone]
+    ) -> typing.Union[int, _UnsetNone]:
         self._basic_py_validation(value, int)
         self._validate_bounds(value)
         return value
@@ -858,8 +868,8 @@ class Float(_Numeric):
 
     def to_py(
             self,
-            value: typing.Union[None, int, float],
-    ) -> typing.Union[None, int, float]:
+            value: typing.Union[int, float, _UnsetNone],
+    ) -> typing.Union[int, float, _UnsetNone]:
         self._basic_py_validation(value, (int, float))
         self._validate_bounds(value)
         return value
@@ -871,8 +881,8 @@ class Perc(_Numeric):
 
     def to_py(
             self,
-            value: typing.Union[None, float, int, str, usertypes.Unset]
-    ) -> typing.Union[None, float, int, usertypes.Unset]:
+            value: typing.Union[float, int, str, _UnsetNone]
+    ) -> typing.Union[float, int, _UnsetNone]:
         self._basic_py_validation(value, (float, int, str))
         if isinstance(value, usertypes.Unset):
             return value
@@ -1067,8 +1077,7 @@ class QtColor(BaseType):
         except ValueError:
             raise configexc.ValidationError(val, "must be a valid color value")
 
-    def to_py(self, value: _StrUnset) -> typing.Union[usertypes.Unset,
-                                                      None, QColor]:
+    def to_py(self, value: _StrUnset) -> typing.Union[_UnsetNone, QColor]:
         self._basic_py_validation(value, str)
         if isinstance(value, usertypes.Unset):
             return value
@@ -1146,14 +1155,9 @@ class QssColor(BaseType):
         return value
 
 
-class Font(BaseType):
+class FontBase(BaseType):
 
-    """A font family, with optional style/weight/size.
-
-    * Style: `normal`/`italic`/`oblique`
-    * Weight: `normal`, `bold`, `100`..`900`
-    * Size: _number_ `px`/`pt`
-    """
+    """Base class for Font/QtFont/FontFamily."""
 
     # Gets set when the config is initialized.
     default_family = None  # type: str
@@ -1229,6 +1233,19 @@ class Font(BaseType):
         cls.default_family = families.to_str(quote=True)
         cls.default_size = default_size
 
+    def to_py(self, value: typing.Any) -> typing.Any:
+        raise NotImplementedError
+
+
+class Font(FontBase):
+
+    """A font family, with optional style/weight/size.
+
+    * Style: `normal`/`italic`/`oblique`
+    * Weight: `normal`, `bold`, `100`..`900`
+    * Size: _number_ `px`/`pt`
+    """
+
     def to_py(self, value: _StrUnset) -> _StrUnsetNone:
         self._basic_py_validation(value, str)
         if isinstance(value, usertypes.Unset):
@@ -1251,7 +1268,7 @@ class Font(BaseType):
         return value
 
 
-class FontFamily(Font):
+class FontFamily(FontBase):
 
     """A Qt font family."""
 
@@ -1275,7 +1292,7 @@ class FontFamily(Font):
         return value
 
 
-class QtFont(Font):
+class QtFont(FontBase):
 
     """A Font which gets converted to a QFont."""
 
@@ -1338,13 +1355,12 @@ class QtFont(Font):
         families = self._parse_families(family_str)
         if hasattr(font, 'setFamilies'):
             # Added in Qt 5.13
-            font.setFamily(families.family)  # type: ignore
+            font.setFamily(families.family)  # type: ignore[arg-type]
             font.setFamilies(list(families))
         else:  # pragma: no cover
             font.setFamily(families.to_str(quote=False))
 
-    def to_py(self, value: _StrUnset) -> typing.Union[usertypes.Unset,
-                                                      None, QFont]:
+    def to_py(self, value: _StrUnset) -> typing.Union[_UnsetNone, QFont]:
         self._basic_py_validation(value, str)
         if isinstance(value, usertypes.Unset):
             return value
@@ -1423,7 +1439,7 @@ class Regex(BaseType):
     def to_py(
             self,
             value: typing.Union[str, typing.Pattern[str], usertypes.Unset]
-    ) -> typing.Union[usertypes.Unset, None, typing.Pattern[str]]:
+    ) -> typing.Union[_UnsetNone, typing.Pattern[str]]:
         """Get a compiled regex from either a string or a regex object."""
         self._basic_py_validation(value, (str, self._regex_type))
         if isinstance(value, usertypes.Unset):
@@ -1514,7 +1530,7 @@ class Dict(BaseType):
 
     def to_py(
             self,
-            value: typing.Union[typing.Dict, usertypes.Unset, None]
+            value: typing.Union[typing.Dict, _UnsetNone]
     ) -> typing.Union[typing.Dict, usertypes.Unset]:
         self._basic_py_validation(value, dict)
         if isinstance(value, usertypes.Unset):
@@ -1713,7 +1729,7 @@ class Proxy(BaseType):
     def to_py(
             self,
             value: _StrUnset
-    ) -> typing.Union[usertypes.Unset, None, QNetworkProxy, _SystemProxy]:
+    ) -> typing.Union[_UnsetNone, QNetworkProxy, _SystemProxy, pac.PACFetcher]:
         self._basic_py_validation(value, str)
         if isinstance(value, usertypes.Unset):
             return value
@@ -1783,7 +1799,7 @@ class FuzzyUrl(BaseType):
 
     """A URL which gets interpreted as search if needed."""
 
-    def to_py(self, value: _StrUnset) -> _StrUnsetNone:
+    def to_py(self, value: _StrUnset) -> typing.Union[QUrl, _UnsetNone]:
         self._basic_py_validation(value, str)
         if isinstance(value, usertypes.Unset):
             return value
@@ -1819,9 +1835,9 @@ class Padding(Dict):
                          fixed_keys=['top', 'bottom', 'left', 'right'],
                          none_ok=none_ok)
 
-    def to_py(  # type: ignore
+    def to_py(  # type: ignore[override]
             self,
-            value: typing.Union[usertypes.Unset, typing.Dict, None],
+            value: typing.Union[typing.Dict, _UnsetNone],
     ) -> typing.Union[usertypes.Unset, PaddingValues]:
         d = super().to_py(value)
         if isinstance(d, usertypes.Unset):
@@ -1893,10 +1909,7 @@ class Url(BaseType):
 
     """A URL as a string."""
 
-    def to_py(
-            self,
-            value: _StrUnset
-    ) -> typing.Union[usertypes.Unset, None, QUrl]:
+    def to_py(self, value: _StrUnset) -> typing.Union[_UnsetNone, QUrl]:
         self._basic_py_validation(value, str)
         if isinstance(value, usertypes.Unset):
             return value
@@ -2010,7 +2023,7 @@ class Key(BaseType):
     def to_py(
             self,
             value: _StrUnset
-    ) -> typing.Union[usertypes.Unset, None, keyutils.KeySequence]:
+    ) -> typing.Union[_UnsetNone, keyutils.KeySequence]:
         self._basic_py_validation(value, str)
         if isinstance(value, usertypes.Unset):
             return value
@@ -2034,7 +2047,7 @@ class UrlPattern(BaseType):
     def to_py(
             self,
             value: _StrUnset
-    ) -> typing.Union[usertypes.Unset, None, urlmatch.UrlPattern]:
+    ) -> typing.Union[_UnsetNone, urlmatch.UrlPattern]:
         self._basic_py_validation(value, str)
         if isinstance(value, usertypes.Unset):
             return value
