@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2019 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2020 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -53,6 +53,8 @@ _MODIFIER_MAP = {
 
 _NIL_KEY = Qt.Key(0)
 
+_ModifierType = typing.Union[Qt.KeyboardModifier, Qt.KeyboardModifiers]
+
 
 def _build_special_names() -> typing.Mapping[Qt.Key, str]:
     """Build _SPECIAL_NAMES dict from the special_names_str mapping below.
@@ -103,18 +105,18 @@ def _build_special_names() -> typing.Mapping[Qt.Key, str]:
         'Dead_Hook': 'Hook',
         'Dead_Horn': 'Horn',
 
-        'Dead_Stroke': '̵',
-        'Dead_Abovecomma': '̓',
-        'Dead_Abovereversedcomma': '̔',
-        'Dead_Doublegrave': '̏',
-        'Dead_Belowring': '̥',
-        'Dead_Belowmacron': '̱',
-        'Dead_Belowcircumflex': '̭',
-        'Dead_Belowtilde': '̰',
-        'Dead_Belowbreve': '̮',
-        'Dead_Belowdiaeresis': '̤',
-        'Dead_Invertedbreve': '̑',
-        'Dead_Belowcomma': '̦',
+        'Dead_Stroke': '\u0335',  # '̵'
+        'Dead_Abovecomma': '\u0313',  # '̓'
+        'Dead_Abovereversedcomma': '\u0314',  # '̔'
+        'Dead_Doublegrave': '\u030f',  # '̏'
+        'Dead_Belowring': '\u0325',  # '̥'
+        'Dead_Belowmacron': '\u0331',  # '̱'
+        'Dead_Belowcircumflex': '\u032d',  # '̭'
+        'Dead_Belowtilde': '\u0330',  # '̰'
+        'Dead_Belowbreve': '\u032e',  # '̮'
+        'Dead_Belowdiaeresis': '\u0324',  # '̤'
+        'Dead_Invertedbreve': '\u0311',  # '̑'
+        'Dead_Belowcomma': '\u0326',  # '̦'
         'Dead_Currency': '¤',
         'Dead_a': 'a',
         'Dead_A': 'A',
@@ -129,10 +131,10 @@ def _build_special_names() -> typing.Mapping[Qt.Key, str]:
         'Dead_Small_Schwa': 'ə',
         'Dead_Capital_Schwa': 'Ə',
         'Dead_Greek': 'Greek',
-        'Dead_Lowline': '̲',
-        'Dead_Aboveverticalline': '̍',
+        'Dead_Lowline': '\u0332',  # '̲'
+        'Dead_Aboveverticalline': '\u030d',  # '̍'
         'Dead_Belowverticalline': '\u0329',
-        'Dead_Longsolidusoverlay': '̸',
+        'Dead_Longsolidusoverlay': '\u0338',  # '̸'
 
         'Memo': 'Memo',
         'ToDoList': 'To Do List',
@@ -167,9 +169,10 @@ def _assert_plain_key(key: Qt.Key) -> None:
     assert not key & Qt.KeyboardModifierMask, hex(key)
 
 
-def _assert_plain_modifier(key: Qt.KeyboardModifier) -> None:
+def _assert_plain_modifier(key: _ModifierType) -> None:
     """Make sure this is a modifier without a key mixed in."""
-    assert not key & ~Qt.KeyboardModifierMask, hex(key)
+    mask = Qt.KeyboardModifierMask
+    assert not key & ~mask, hex(key)  # type: ignore[operator]
 
 
 def _is_printable(key: Qt.Key) -> bool:
@@ -177,7 +180,7 @@ def _is_printable(key: Qt.Key) -> bool:
     return key <= 0xff and key not in [Qt.Key_Space, _NIL_KEY]
 
 
-def is_special_hint_mode(key: Qt.Key, modifiers: Qt.KeyboardModifier) -> bool:
+def is_special_hint_mode(key: Qt.Key, modifiers: _ModifierType) -> bool:
     """Check whether this key should clear the keychain in hint mode.
 
     When we press "s<Escape>", we don't want <Escape> to be handled as part of
@@ -192,7 +195,7 @@ def is_special_hint_mode(key: Qt.Key, modifiers: Qt.KeyboardModifier) -> bool:
                               Qt.KeypadModifier])
 
 
-def is_special(key: Qt.Key, modifiers: Qt.KeyboardModifier) -> bool:
+def is_special(key: Qt.Key, modifiers: _ModifierType) -> bool:
     """Check whether this key requires special key syntax."""
     _assert_plain_key(key)
     _assert_plain_modifier(modifiers)
@@ -244,7 +247,7 @@ def _remap_unicode(key: Qt.Key, text: str) -> Qt.Key:
 
 
 def _check_valid_utf8(s: str,
-                      data: typing.Union[Qt.Key, Qt.KeyboardModifier]) -> None:
+                      data: typing.Union[Qt.Key, _ModifierType]) -> None:
     """Make sure the given string is valid UTF-8.
 
     Makes sure there are no chars where Qt did fall back to weird UTF-16
@@ -254,7 +257,7 @@ def _check_valid_utf8(s: str,
         s.encode('utf-8')
     except UnicodeEncodeError as e:  # pragma: no cover
         raise ValueError("Invalid encoding in 0x{:x} -> {}: {}"
-                         .format(data, s, e))
+                         .format(int(data), s, e))
 
 
 def _key_to_string(key: Qt.Key) -> str:
@@ -276,15 +279,16 @@ def _key_to_string(key: Qt.Key) -> str:
     return result
 
 
-def _modifiers_to_string(modifiers: Qt.KeyboardModifier) -> str:
+def _modifiers_to_string(modifiers: _ModifierType) -> str:
     """Convert the given Qt::KeyboardModifiers to a string.
 
     Handles Qt.GroupSwitchModifier because Qt doesn't handle that as a
     modifier.
     """
     _assert_plain_modifier(modifiers)
-    if modifiers & Qt.GroupSwitchModifier:
-        modifiers &= ~Qt.GroupSwitchModifier  # type: ignore
+    altgr = Qt.GroupSwitchModifier
+    if modifiers & altgr:  # type: ignore[operator]
+        modifiers &= ~altgr  # type: ignore[operator, assignment]
         result = 'AltGr+'
     else:
         result = ''
@@ -375,7 +379,7 @@ class KeyInfo:
     """
 
     key = attr.ib()  # type: Qt.Key
-    modifiers = attr.ib()  # type: Qt.KeyboardModifier
+    modifiers = attr.ib()  # type: _ModifierType
 
     @classmethod
     def from_event(cls, e: QKeyEvent) -> 'KeyInfo':
@@ -388,7 +392,7 @@ class KeyInfo:
         modifiers = e.modifiers()
         _assert_plain_key(key)
         _assert_plain_modifier(modifiers)
-        return cls(key, modifiers)
+        return cls(key, typing.cast(Qt.KeyboardModifier, modifiers))
 
     def __hash__(self) -> int:
         """Convert KeyInfo to int before hashing.
@@ -451,7 +455,7 @@ class KeyInfo:
             return ''
 
         text = QKeySequence(self.key).toString()
-        if not self.modifiers & Qt.ShiftModifier:
+        if not self.modifiers & Qt.ShiftModifier:  # type: ignore[operator]
             text = text.lower()
         return text
 
@@ -508,7 +512,7 @@ class KeySequence:
         """Iterate over KeyInfo objects."""
         for key_and_modifiers in self._iter_keys():
             key = Qt.Key(int(key_and_modifiers) & ~Qt.KeyboardModifierMask)
-            modifiers = Qt.KeyboardModifiers(  # type: ignore
+            modifiers = Qt.KeyboardModifiers(  # type: ignore[call-overload]
                 int(key_and_modifiers) & Qt.KeyboardModifierMask)
             yield KeyInfo(key=key, modifiers=modifiers)
 
@@ -516,29 +520,23 @@ class KeySequence:
         return utils.get_repr(self, keys=str(self))
 
     def __lt__(self, other: 'KeySequence') -> bool:
-        # pylint: disable=protected-access
         return self._sequences < other._sequences
 
     def __gt__(self, other: 'KeySequence') -> bool:
-        # pylint: disable=protected-access
         return self._sequences > other._sequences
 
     def __le__(self, other: 'KeySequence') -> bool:
-        # pylint: disable=protected-access
         return self._sequences <= other._sequences
 
     def __ge__(self, other: 'KeySequence') -> bool:
-        # pylint: disable=protected-access
         return self._sequences >= other._sequences
 
     def __eq__(self, other: object) -> bool:
-        # pylint: disable=protected-access
         if not isinstance(other, KeySequence):
             return NotImplemented
         return self._sequences == other._sequences
 
     def __ne__(self, other: object) -> bool:
-        # pylint: disable=protected-access
         if not isinstance(other, KeySequence):
             return NotImplemented
         return self._sequences != other._sequences
@@ -560,7 +558,9 @@ class KeySequence:
     def __getitem__(self, item: slice) -> 'KeySequence':
         ...
 
-    def __getitem__(self, item):
+    def __getitem__(
+            self, item: typing.Union[int, slice]
+    ) -> typing.Union[KeyInfo, 'KeySequence']:
         if isinstance(item, slice):
             keys = list(self._iter_keys())
             return self.__class__(*keys[item])
@@ -569,7 +569,9 @@ class KeySequence:
             return infos[item]
 
     def _iter_keys(self) -> typing.Iterator[int]:
-        return itertools.chain.from_iterable(self._sequences)
+        sequences = typing.cast(typing.Iterable[typing.Iterable[int]],
+                                self._sequences)
+        return itertools.chain.from_iterable(sequences)
 
     def _validate(self, keystr: str = None) -> None:
         for info in self:
@@ -650,7 +652,7 @@ class KeySequence:
         if (modifiers == Qt.ShiftModifier and
                 _is_printable(key) and
                 not ev.text().isupper()):
-            modifiers = Qt.KeyboardModifiers()
+            modifiers = Qt.KeyboardModifiers()  # type: ignore[assignment]
 
         # On macOS, swap Ctrl and Meta back
         # WORKAROUND for https://bugreports.qt.io/browse/QTBUG-51293
